@@ -55,6 +55,11 @@ class H2OAutoML(H2OAutoMLParams, H2OSupervisedAlgorithmWithFoldColumn, H2OAutoML
                  keepCrossValidationModels=False,
                  keepCrossValidationFoldAssignment=False,
                  exportCheckpointsDir=None,
+                 distribution="AUTO",
+                 tweediePower=1.5,
+                 quantileAlpha=0.5,
+                 huberAlpha=0.9,
+                 customDistributionFunc=None,
                  labelCol="label",
                  foldCol=None,
                  weightCol=None,
