@@ -42,7 +42,6 @@ class H2ORuleFitClassifier(H2ORuleFit):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  seed=-1,
                  algorithm="AUTO",
                  minRuleLength=3,
@@ -50,6 +49,8 @@ class H2ORuleFitClassifier(H2ORuleFit):
                  maxNumRules=-1,
                  modelType="RULES_AND_LINEAR",
                  ruleGenerationNtrees=50,
+                 removeDuplicates=True,
+                 lambdaValue=None,
                  modelId=None,
                  distribution="AUTO",
                  labelCol="label",
