@@ -32,6 +32,7 @@ class H2OGBMRegressor(H2OGBM):
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -42,13 +43,13 @@ class H2OGBMRegressor(H2OGBM):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  learnRate=0.1,
                  learnRateAnnealing=1.0,
                  sampleRate=1.0,
                  colSampleRate=1.0,
                  maxAbsLeafnodePred=1.7976931348623157E308,
                  predNoiseBandwidth=0.0,
+                 interactionConstraints=None,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
