@@ -1,4 +1,3 @@
-
 #
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
@@ -16,45 +15,51 @@
 # limitations under the License.
 #
 
-from ai.h2o.sparkling import Initializer
-from ai.h2o.sparkling.ml.H2OStageBase import H2OStageBase
-from ai.h2o.sparkling.ml.Utils import Utils
-from ai.h2o.sparkling.ml.models import H2OMOJOModel
-from ai.h2o.sparkling.ml.params.H2OWord2VecParams import H2OWord2VecParams
+from warnings import warn
 from pyspark import keyword_only
-from pyspark.ml.wrapper import JavaEstimator
-from pyspark.ml.param.shared import HasInputCol, HasOutputCol
+from ai.h2o.sparkling import Initializer
+from ai.h2o.sparkling.ml.Utils import Utils
+from ai.h2o.sparkling.ml.features.H2OWord2VecBase import H2OWord2VecBase
+from ai.h2o.sparkling.ml.models.H2OWord2VecMOJOModel import H2OWord2VecMOJOModel
+from ai.h2o.sparkling.ml.params.H2OWord2VecParams import H2OWord2VecParams
 
-class H2OWord2Vec(HasInputCol, HasOutputCol, H2OWord2VecParams, H2OStageBase, JavaEstimator):
+
+class H2OWord2Vec(H2OWord2VecParams, H2OWord2VecBase):
 
     @keyword_only
     def __init__(self,
-                 initLearningRate=0.025,
-                 modelId=None,
+                 preTrained=None,
+                 columnsToCategorical=[],
+                 inputCol=None,
+                 keepBinaryModels=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
+                 convertInvalidNumbersToNa=False,
+                 outputCol="Word2Vec__output",
+                 validationDataFrame=None,
+                 convertUnknownCategoricalLevelsToNa=False,
+                 splitRatio=1.0,
                  vecSize=100,
-                 outputCol="H2OWord2Vec_output",
                  windowSize=5,
                  sentSampleRate=0.001,
-                 maxRuntimeSecs=0.0,
-                 minWordFreq=5,
                  normModel="HSM",
-                 exportCheckpointsDir=None,
-                 wordModel="SkipGram",
                  epochs=5,
-                 inputCol=None):
+                 minWordFreq=5,
+                 initLearningRate=0.025,
+                 wordModel="SkipGram",
+                 modelId=None,
+                 maxRuntimeSecs=0.0,
+                 exportCheckpointsDir=None):
         Initializer.load_sparkling_jar()
         super(H2OWord2Vec, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.features.H2OWord2Vec", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
+
+        if 'interactionPairs' in kwargs:
+            warn("Interaction pairs are not supported!")
         self._set(**kwargs)
+        self._transfer_params_to_java()
 
-    def _create_model(self, java_model):
-        return H2OMOJOModel(java_model)
-
-    def setInputCol(self, value):
-        return self._set(inputCol=value)
-
-    def setOutputCol(self, value):
-        return self._set(outputCol=value)
-     
\ No newline at end of file
+    def _create_model(self, javaModel):
+        return H2OWord2VecMOJOModel(javaModel)
